@@ -57,10 +57,10 @@ class MCDA:
         df_data.insert(loc=0,
                     column='alternatives',
                     value=alt_labels)
-        dfo = df_data
+        dfo = copy.deepcopy(df_data)
 
-        self.df_original = copy.copy(dfo)
-        self.df_calc = copy.copy(dfo)
+        self.df_original = copy.deepcopy(dfo)
+        self.df_calc = copy.deepcopy(dfo)
         self.decision = []
 
     def set_weights_manually(self, weights, free=False):
